@@ -463,7 +463,7 @@ def create_book(paragraphs_from, paragraphs_to, meta, output_path, template, sty
             <link rel="stylesheet" href="main.css">
             <link rel="preconnect" href="https://fonts.gstatic.com">
             <link href="https://fonts.googleapis.com/css2?family=Noto+Serif:wght@400&display=swap" rel="stylesheet">
-            <link href="https://fonts.googleapis.com/css2?family=Raleway&display=swap" rel="stylesheet">
+            <link href="https://fonts.googleapis.com/css2?family=Oswald:wght@300;400&display=swap" rel="stylesheet">
             <title>Lingtrain Magic Book</title>
             {css}
         </head>
@@ -472,14 +472,6 @@ def create_book(paragraphs_from, paragraphs_to, meta, output_path, template, sty
         # --------------------BOOK
         res_html.write("<div class='dt cont'>")
 
-        # --------------------IMG
-        # res_html.write("<div class='dt-row'><div class='par dt-cell'>")
-        # res_html.write("<img class='flag-img' src='img/flags/flag-ru-h.svg'/>")
-        # res_html.write("</div>")
-        # res_html.write("<div class='par dt-cell'>")
-        # res_html.write("<img class='flag-img' src='img/flags/flag-de-h.svg'/>")
-        # res_html.write("</div></div>")
-
         #--------------------TITLE and AUTHOR
         res_html.write("<div class='dt-row header'><div class='par dt-cell'>")
 
@@ -504,7 +496,7 @@ def create_book(paragraphs_from, paragraphs_to, meta, output_path, template, sty
         # --------------------DIVIDER
         res_html.write("<div class='dt-row header'>")
         res_html.write(
-            "<div class='dt-cell divider'><img class='divider-img' src='img/divider1.svg'/></div><div class='dt-cell divider'><img class='divider-img' src='img/divider1.svg'/></div>")
+            "<div class='dt-cell divider'><img class='divider-img' src='https://habrastorage.org/webt/nr/av/qa/nravqa-wy0sg8kgwr3cfli8veym.png'/></div><div class='dt-cell divider'><img class='divider-img' src='https://habrastorage.org/webt/nr/av/qa/nravqa-wy0sg8kgwr3cfli8veym.png'/></div>")
         res_html.write("</div>")
 
         # --------------------FIRST HEADERS IF EXIST
@@ -526,7 +518,7 @@ def create_book(paragraphs_from, paragraphs_to, meta, output_path, template, sty
             elif p_from == DIVIDER_MARK:
                 res_html.write("<div class='dt-row header'>")
                 res_html.write(
-                    "<div class='dt-cell divider'><img class='divider-img' src='img/divider1.svg'/></div><div class='dt-cell divider'><img class='divider-img' src='img/divider1.svg'/></div>")
+                    "<div class='dt-cell divider'><img class='divider-img' src='https://habrastorage.org/webt/nr/av/qa/nravqa-wy0sg8kgwr3cfli8veym.png'/></div><div class='dt-cell divider'><img class='divider-img' src='https://habrastorage.org/webt/nr/av/qa/nravqa-wy0sg8kgwr3cfli8veym.png'/></div>")
                 res_html.write("</div>")
             else:
                 res_html.write("<div class='dt-row'><div class='par dt-cell'>")
@@ -564,7 +556,7 @@ def create_polybook(lang_ordered, paragraphs, delimeters, metas, output_path, te
             <link rel="stylesheet" href="main.css">
             <link rel="preconnect" href="https://fonts.gstatic.com">
             <link href="https://fonts.googleapis.com/css2?family=Noto+Serif:wght@400&display=swap" rel="stylesheet">
-            <link href="https://fonts.googleapis.com/css2?family=Raleway&display=swap" rel="stylesheet">
+            <link href="https://fonts.googleapis.com/css2?family=Oswald:wght@300;400&display=swap" rel="stylesheet">
             <title>Lingtrain Magic Book</title>
             {css}
         </head>
@@ -591,7 +583,7 @@ def create_polybook(lang_ordered, paragraphs, delimeters, metas, output_path, te
         res_html.write("<div class='dt-row header'>")
         for _ in range(langs_count):
             res_html.write(
-                "<div class='dt-cell divider'><img class='divider-img' src='img/divider1.svg'/></div>")
+                "<div class='dt-cell divider'><img class='divider-img' src='https://habrastorage.org/webt/nr/av/qa/nravqa-wy0sg8kgwr3cfli8veym.png'/></div>")
         res_html.write("</div>")
 
         # --------------------PARAGRAPHS
@@ -602,7 +594,7 @@ def create_polybook(lang_ordered, paragraphs, delimeters, metas, output_path, te
             real_par_id = delimeters[actual_paragraphs_id]
 
             while next_meta_par_id <= real_par_id:
-                write_next_polyheader(res_html, next_mark, metas["items"], lang_ordered)
+                write_next_polyheader(res_html, next_mark, metas, lang_ordered)
                 next_mark, next_meta_par_id = get_next_meta_par_id(metas)
             
             res_html.write("<div class='dt-row'>")
@@ -635,7 +627,9 @@ def get_next_meta_par_id(metas):
     return next_mark, min_par_id
 
 
-def write_next_polyheader(writer, next_mark, metas, lang_ordered):
+def write_next_polyheader(writer, next_mark, metas_dict, lang_ordered):
+    metas = metas_dict["items"]
+    main_lang_code = metas_dict["main_lang_code"]
     writer.write("<div class='dt-row header'>")
     for lang in lang_ordered:
         meta = metas[lang][next_mark]
@@ -646,8 +640,11 @@ def write_next_polyheader(writer, next_mark, metas, lang_ordered):
         writer.write("<div class='par dt-cell'>")
         writer.write(f'<{HEADER_HTML_MAPPING[next_mark]}>' + val[0] + f'</{HEADER_HTML_MAPPING[next_mark]}>')
         writer.write("</div>")
-            
     writer.write("</div>")
+    #pop main lang if not yet popped
+    if main_lang_code not in lang_ordered:
+        meta = metas[main_lang_code][next_mark]
+        if meta: meta.pop(0)
 
 
 def write_header(writer, meta, mark, occurence, add_divider=False):
@@ -752,7 +749,20 @@ CSS_GENERAL = """
 }
 
 h1, h2, h3, h4, h5 {
-    font-family: 'Raleway', cursive;
+    font-family: 'Oswald', cursive;
+}
+
+h1 {
+    font-weight: 400;
+}
+
+h2 {
+    text-transform: uppercase;
+    font-weight: 400;
+}
+
+h3 {
+    font-weight: 300;
 }
 
 .cont {
@@ -774,17 +784,18 @@ h1, h2, h3, h4, h5 {
 }
 
 .dt-row:nth-child(even):not(.header) {
-    background: #fafafa;
+    background: #fefefe;
 }
 
 .dt-row:nth-child(even):not(.header) > .dt-cell:not(.divider) {
-    border-top: 1px solid #e0e0e0;
-    border-bottom: 1px solid #e0e0e0;
+    border-top: 1px solid #f0f0f0;
+    border-bottom: 1px solid #f0f0f0;
 }
 
 .dt-cell {
     display: table-cell;
     width: %COL_WIDTH% !important;
+    word-break: break-word;
 }
 
 .dt-cell-colspan {
@@ -819,49 +830,15 @@ h1, h2, h3, h4, h5 {
 
 STYLES = {
     "pastel_fill": [
-        '{"background": "#A2E4B8", "color": "black", "border-bottom": "0px solid red"}',
-        '{"background": "#FFC1CC", "color": "black"}',
-        '{"background": "#9BD3DD", "color": "black"}',
-        '{"background": "#FFFCC9", "color": "black"}'
-        ],
+    '{"background": "#cfefd7", "color": "black"}',
+    '{"background": "#fadce2", "color": "black"}',
+    '{"background": "#cce7eb", "color": "black"}',
+    '{"background": "#fefbd6", "color": "black"}'
+    ],
     "pastel_start": [
-        '{"background": "linear-gradient(90deg, #A2E4B8 0px, #fff 150px)"}',
-        '{"background": "linear-gradient(90deg, #FFC1CC 0px, #fff 150px)"}',
-        '{"background": "linear-gradient(90deg, #9BD3DD 0px, #fff 150px)"}',
-        '{"background": "linear-gradient(90deg, #FFFCC9 0px, #fff 150px)"}'    
+        '{"background": "linear-gradient(90deg, #cfefd7 0px, #ffffff00 150px)"}',
+        '{"background": "linear-gradient(90deg, #fadce2 0px, #ffffff00 150px)"}',
+        '{"background": "linear-gradient(90deg, #cce7eb 0px, #ffffff00 150px)"}',
+        '{"background": "linear-gradient(90deg, #fefbd6 0px, #ffffff00 150px)"}'  
         ]
-
-# styles3 = [
-#     '{ }',
-#     '{"background": "#fafad2", "color": "black"}',
-#     ]
-
-
-# styles4 = [
-#     '{ }',
-#     '{"background": "crimson", "color": "white", "border-radius": "15px"}',
-#     ]
-
-# styles5 = [
-#     '{ }',
-#     '{"background": "linear-gradient(45deg, #85FFBD 0%, #FFFB7D 100%)"}',
-#     ]
-
-# styles6 = [
-#     '{"background": "linear-gradient(90deg, #FDEB71 0%, #fff 20%)"}',
-#     '{"background": "linear-gradient(90deg, #ABDCFF 0%, #fff 20%)"}',
-#     '{"background": "linear-gradient(90deg, #FEB692 0%, #fff 20%)"}',
-#     '{"background": "linear-gradient(90deg, #CE9FFC 0%, #fff 20%)"}',
-#     '{"background": "linear-gradient(90deg, #81FBB8 0%, #fff 20%)"}'
-#     ]
-
-# styles7 = [
-#     '{"background": "linear-gradient(90deg, #FDEB71 0px, #fff 150px)"}',
-#     '{"background": "linear-gradient(90deg, #ABDCFF 0px, #fff 150px)"}',
-#     '{"background": "linear-gradient(90deg, #FEB692 0px, #fff 150px)"}',
-#     '{"background": "linear-gradient(90deg, #CE9FFC 0px, #fff 150px)"}',
-#     '{"background": "linear-gradient(90deg, #81FBB8 0px, #fff 150px)"}'
-#     ]
-
-
 }
\ No newline at end of file
